#include "common.h"

void packet_error_bits(struct pcap_pkthdr* pcap_header, u_char* packet, int with_rate);

int main(int argc, char** argv) /*{{{*/
{
	if (argc < 3)
	{
		printf("Usage: %s <pcap> <with rate?>\n", argv[0]);
		exit(0);
	}

	char pcap_error[PCAP_ERRBUF_SIZE];
	pcap_t* pcap = NULL;
	struct bpf_program bpf;
	u_char* packet = NULL;
	struct pcap_pkthdr pcap_header;

	int with_rate = atoi(argv[2]);

	pcap = pcap_open_offline(argv[1], pcap_error);
	if (pcap == NULL)
	{
		printf("pcap failed: %s\n", pcap_error);
		return 2;
	}

	/* Filter out only the UDP packets */
	//pcap_compile(pcap, &bpf, PCAP_FILTER, 0, 0);
	//pcap_setfilter(pcap, &bpf);

	while ((packet = (u_char*)pcap_next(pcap, &pcap_header)) != NULL)
	{
		packet_error_bits(&pcap_header, packet, with_rate);
	}

	pcap_close(pcap);	

	return 0;
} /*}}}*/
void packet_error_bits(struct pcap_pkthdr* pcap_header, u_char* packet, int with_rate) /*{{{*/
{
	int len = pcap_header->caplen;
	int i,j;

	int base = 0x30;
	double rate = radiotap_rate(packet);

	int skip_len = radiotap_len(packet) + sizeof(struct wlan_hdr) +
		LLCSIZE + IPSIZE + UDPSIZE - 2; // 2 is because broadcom monitor does not put in qos
	packet += skip_len;
	len -= skip_len + 4; // 4 is for the 80211 checksum

	int bad_bits = 0;

	/* todo: find a way not to assume the first 36 bytes are fine */
	for (i = 36; i < len ; i++) /* Skip over 36 bytes of the packet due to iperf header */
	{
		/* Byte is bad, what about bits? */
		if (packet[i] != base+(i%10)) 
		{
			/* Find bad bits */
			for (j = 0; j < 8; j++)
			{
				/* Which bit is bad */
				if (((packet[i] >> j & 0x1)) != (((base+(i%10)) >> j & 0x1)))
				printf("%d ", ((i-36)*8)+j);
				bad_bits = 1;
			}
		}
	}
	if (bad_bits)
	{
		if (with_rate)
		{
			printf("%f ", rate);
		}
		printf("\n");
	}
} /*}}}*/
