#!/usr/bin/ruby

require 'rubygems'
require 'base32/crockford'

packets = []
sim_packets = []
sim_spaces = []
MAX_PACKETS = 1000 

# Read in the simulator data
STDIN.each do |line|
	linearr = line.split(%r{\s})
	
	time = linearr[0].to_i
	type = linearr[1]
	seqnum = linearr[2].to_i
	len = linearr[3].to_i
	typequal = linearr[4]

	rate = 0.0
	if (linearr.length > 5)
		rate = linearr[5].to_f
	end

	starttime = time
	endtime = time + len
	
	packet = [seqnum, starttime, endtime, typequal, rate]

	if (type == "PACKET")
		packets.push(packet)
	end

	if (type == "SIM-PACKET")
		sim_packets.push(packet)
		if (typequal == "SPACE")
			sim_spaces.push(packet)
		end
	end

	# Stop when we get MAX_PACKETS
	if (packets.length > MAX_PACKETS)
		break
	end
end

# for all spaces, remove anything that is under the space 
sim_packets.delete_if {|packet|
	i = false 
	if (packet[3] != "SPACE")
		sim_spaces.each do |space|
			if ((packet[1] > space[1] && packet[1] < space[2]) || 
					(packet[2] > space[1] && packet[2] < space[2]))
				i = true
				break
			end
		end
	end
	i
}

# for all nacks, remove anything that overlaps the nack, that is not a space
sim_packets.delete_if {|packet|
	i = false 
	if (packet[3] != "NACK" && packet[3] != "SPACE")
		sim_packets.each do |packet2|
			if (packet2[3] == "NACK" && 
					((packet[1] >= packet2[1] && packet[1] <= packet2[2]) || 
					(packet[2] >= packet2[1] && packet[2] <= packet2[2])))
				i = true
				break
			end
		end
	end
	i
}

#ScaleMajor = increment:5000 start:0 gridcolor:white
# Period     = from:0 till:#{packets.last[2]}
print "
Colors = 
	id:BLACK value:black
	id:GOOD_RETRY value:rgb(0.47,0.47,0.47) legend:Good_Retry
	id:BAD_RETRY value:yellow legend:Bad_Retry
	id:BAD_BLOCK value:orange legend:Bad_Block
	id:GOOD_BLOCK value:rgb(0.47,0.47,0.47) legend:Good_Block
	id:GOOD_DATA value:rgb(0.47,0.47,0.47) legend:Good_Data
	id:BAD_DATA value:red legend:Bad_Data
	id:NACK value:rgb(0.4,0,1) legend:Nack
	id:SPACE value:rgb(1,1,1)
	id:1.0 value:rgb(0.91,0.5,0.08) legend:1.0
	id:2.0 value:rgb(0,0.5,1) legend:2.0
	id:5.5 value:rgb(0.75,1,0.25) legend:5.5
	id:6.0 value:rgb(0.67,0,0.33)   legend:6.0
	id:9.0 value:rgb(0.58,0.5,0.42)   legend:9.0
	id:11.0 value:rgb(0.5,0,0.5)  legend:11.0
	id:12.0 value:rgb(0.42,1,0.58)  legend:12.0
	id:18.0 value:rgb(0.33,0,0.67)  legend:18.0
	id:24.0 value:rgb(0.25,0.8,0.75)  legend:24.0
	id:36.0 value:rgb(0.16,0,0.83)  legend:36.0
	id:48.0 value:rgb(0.08,1,0.91)  legend:48.0
	id:54.0 value:rgb(0.83,0,0.16)    legend:54.0

ImageSize  = width:20000 height:200
PlotArea   = width:19000 height:100 left:90 bottom:30
Period     = from:0 till:900000
BackgroundColors = bars:BLACK canvas:white
TimeAxis   = orientation:horizontal
Legend = orientation:horizontal position:top

PlotData=
	width:25 mark:(line,white) align:center fontsize:S textcolor:black color:white
"

# Actual Packets
#  
packets.each do |packet|
	if (packet[3] != "BAD_DATA" && packet[3] != "BAD_RETRY")
		print "\tbar:Actual from:#{packet[1]} till:#{packet[2]} color:#{packet[3]} text:#{Base32::Crockford.encode(packet[0]%32)} shift:(0,-3) fontsize:XS\n"
	end
end

# Simulated Packets 
sim_packets.each do |packet|
	if (packet[3] != "BAD_DATA" && packet[3] != "BAD_RETRY")
		if (packet[3] == "SPACE") 
			print "\tbar:Simulated from:#{packet[1]} till:#{packet[2]} color:#{packet[3]}\n"
		else
			if (packet[3] == "NACK")
				print "\tbar:Simulated from:#{packet[1]} till:#{packet[2]} color:#{packet[3]}\n"
			else
				print "\tbar:Simulated from:#{packet[1]} till:#{packet[2]} color:#{packet[3]} text:#{Base32::Crockford.encode(packet[0]%32)} shift:(0,-3) fontsize:XS\n"
			end
		end
	end
end

# Rates
packets.each do |packet|
	print "\tbar:Rate from:#{packet[1]} till:#{packet[2]} color:#{packet[4]}\n"
end
